#include <iostream>
#include <vector>
#include <queue>
#include <tuple>
#include <map>

#define ENDL '\n'

namespace {
template <class T>
using vec = std::vector<T>;

template <class T>
using mat = vec<vec<T>>;

auto dfs(const mat<char>& labyrinth, mat<int>& dist, mat<bool>& visited, std::map<std::pair<int, int>, std::pair<int, int>>& rev_neighbors, int i, int j) {
    if (i < 0 || i >= labyrinth.size() || j < 0 || j >= labyrinth[0].size()) {
        return 0;
    }

    auto& res = dist[i][j];
    if (res == -1) {
        if (visited[i][j]) {
            return -1;
        }

        visited[i][j] = true;

        auto curr_dir = labyrinth[i][j];
        auto k = i, l = j;

        switch (curr_dir) {
        case '>': ++l; break;
        case '<': --l; break;
        case 'v': ++k; break;
        case '^': --k; break;
        }

        rev_neighbors.emplace(std::make_pair(k, l), std::make_pair(i, j));

        auto ret = dfs(labyrinth, dist, visited, rev_neighbors, k, l);
        // std::cout << k << ", " << l << " -> " << ret << std::endl;

        if (ret != -1) {
            res = ret + 1;
        } else {
            res = -1;
        }
    }

    return res;
}

auto update(const mat<char>& labyrinth, mat<int>& dist, mat<bool>& visited, std::map<std::pair<int, int>, std::pair<int, int>>& rev_neighbors, int i, int j) {
    dist[i][j] = -1;
    dfs(labyrinth, dist, visited, rev_neighbors, i, j);

    auto act_pos = std::make_pair(i, j);
    auto old_pos = act_pos;
    for (auto it = rev_neighbors.find(old_pos); it != rev_neighbors.end(); it = rev_neighbors.find(old_pos)) {
        if (it->second == act_pos) {
            break;
        }

        dist[it->second.first][it->second.second] = dist[old_pos.first][old_pos.second] + 1;
        old_pos = it->second;
    }
}
}

int main() {
    std::ios_base::sync_with_stdio(false);
    std::cin.tie(nullptr);
    std::cout.tie(nullptr);

    int n, m;
    std::cin >> n >> m;

    mat<char> labyrinth(n, vec<char>(m));
    for (auto& row : labyrinth) {
        for (auto& col : row) {
            std::cin >> col;
        }
    }

    mat<bool> visited(n, vec<bool>(m));
    mat<int> dist(n, vec<int>(m, -1));
    std::map<std::pair<int, int>, std::pair<int, int>> rev_neighbors;

    for (auto i = 0; i < n; ++i) {
        for (auto j = 0; j < m; ++j) {
            if (dist[i][j] != -1) {
                continue;
            }

            dfs(labyrinth, dist, visited, rev_neighbors, i, j);
        }
    }

    int q;
    std::cin >> q;

    int sx, sy, cx, cy;
    char cd;

    while (q--) {
        std::cin >> sx >> sy >> cx >> cy >> cd;
        --sx, --sy, --cx, --cy;

        auto dist_copy = dist;

        auto old = labyrinth[cx][cy];
        labyrinth[cx][cy] = cd;

        for (auto& row : visited) {
            std::fill(row.begin(), row.end(), false);
        }

        update(labyrinth, dist_copy, visited, rev_neighbors, cx, cy);

        if (cx != sx && cy != sy) {
            update(labyrinth, dist_copy, visited, rev_neighbors, sx, sy);

            /*for (auto& row : dist_copy) {
                for (auto& col : row) {
                    std::cout << col << " ";
                }
                std::cout << std::endl;
            }*/
        }

        auto res = dist_copy[sx][sy];
        std::cout << (res == -1 ? 0 : res) << std::endl;

        labyrinth[cx][cy] = old;
    }

    return 0;
}
