#include <algorithm>
#include <iostream>
#include <cstring>
#include <vector>
#include <queue>
#include <set>
#include <map>

using namespace std;

const int MAXN = 4e5 + 5;
const int inf = 2e9 + 5;

struct Event
{
    /*
    0 -> ask
    1 -> segment
    */
    bool type;
    int sortVal;

    //0
    pair <int, int> state;

    //1
    int finish;

    Event(){}
    Event(bool type, int sortVal)
    {
        this->type = type;
        this->sortVal = sortVal;
    }
};

bool operator <(Event A, Event B)
{
    if(A.sortVal!=B.sortVal) return A.sortVal<B.sortVal;
    return A.type>B.type;
}

int adVal[MAXN][2];

map <int, int> code;
void compress(vector <pair <int, int>> &v)
{
    set <int> s;
    for(pair <int, int> item: v)
    {
        s.insert(item.first);
        s.insert(item.second);
    }

    int ind = 0;
    for(int x: s)
    {
        code[x] = ind;
        ind++;
    }
}

struct FenwickTree
{
    int tree[MAXN];

    FenwickTree()
    {
        memset(this->tree, 0, sizeof(this->tree));
    }

    void update(int ind, int change)
    {
        ind++;
        while(ind<MAXN)
        {
            tree[ind] += change;
            ind += ind&(-ind);
        }
    }

    int getSum(int ind)
    {
        ind++;
        int sum = 0;

        while(ind>0)
        {
            sum += tree[ind];
            ind -= ind&(-ind);
        }

        return sum;
    }

    int query(int l, int r)
    {
        if(r<code.begin()->first || l>prev(code.end())->first) return 0;

        l = code.lower_bound(l)->second;
        r = prev(code.upper_bound(r))->second;
        if(l>r) return 0;

        return getSum(r) - getSum(l-1);
    }
};

int n, m;
map <int, int> start2Cnt;
vector <pair <int, int>> v;

FenwickTree T = FenwickTree();
int checkStart(int start)
{
    return T.query(start+m, inf);
}

void init()
{
    vector <Event> yoanko;
    for(pair <int, int> x: v)
    {
        Event e = Event(true, x.first);
        e.finish = x.second;

        yoanko.push_back(e);
    }
    for(int i = 0;i<v.size();i++)
    {
        Event e1 = Event(false, v[i].first);
        e1.state = {i, 0};
        yoanko.push_back(e1);

        Event e2 = Event(false, v[i].first+m);
        e2.state = {i, 1};
        yoanko.push_back(e2);
    }

    sort(yoanko.begin(), yoanko.end());

    priority_queue <int, vector <int>, greater <int>> pq;
    for(Event e: yoanko)
    {
        if(e.type==false)
        {
            while(pq.empty()==false && pq.top()<e.sortVal+m) pq.pop();
            adVal[e.state.first][e.state.second] = pq.size();
        }
        else
        {
            pq.push(e.finish);
        }
    }
}

int main()
{
    ios::sync_with_stdio(false);
    cin.tie(NULL);

    cin >> n >> m;

    for(int i = 0;i<n;i++)
    {
        int a, b;
        cin >> a >> b;

        v.push_back({a, b});
    }

    sort(v.begin(), v.end());
    init();

    int answer = 0, ind = n - 1, maxOther = -MAXN;
    for(int i = n-1;i>=0;i--)
    {
        while(ind>=0 && v[ind].first-v[i].first>=m)
        {
            maxOther = max(maxOther, adVal[ind][0]);
            ind--;
        }

        answer = max(answer, adVal[i][0] + maxOther);
        answer = max(answer, adVal[i][0] + adVal[i][1]);
    }

    cout << answer << '\n';
}
