#include <iostream>
#include <cstring>
#include <vector>

using namespace std;

const int MAXN = 105;

int n, m;
string a[MAXN];

int node[MAXN][MAXN], exitNode = 1;
int nxt[MAXN*MAXN];

bool isCycle[MAXN];
int used[MAXN*MAXN];
int compressedNodeVal[MAXN];

int getNxt(int i, int j, char c)
{
    pair <int, int> jump;
    if(c=='<') jump = {0, -1};
    else if(c=='>') jump = {0, +1};
    else if(c=='v') jump = {+1, 0};
    else if(c=='^') jump = {-1, 0};

    int nxtI = i + jump.first;
    int nxtJ = j + jump.second;

    if(nxtI>=0 && nxtI<n && nxtJ>=0 && nxtJ<m) return node[nxtI][nxtJ];
    return exitNode;
}

void init()
{
    int nodeInd = 2;
    for(int i = 0;i<n;i++)
    {
        for(int j = 0;j<m;j++)
        {
            node[i][j] = nodeInd;
            nodeInd++;
        }
    }

    for(int i = 0;i<n;i++)
    {
        for(int j = 0;j<m;j++)
        {
            pair <int, int> jump;
            if(a[i][j]=='<') jump = {0, -1};
            else if(a[i][j]=='>') jump = {0, +1};
            else if(a[i][j]=='v') jump = {+1, 0};
            else if(a[i][j]=='^') jump = {-1, 0};

            int nxtI = i + jump.first;
            int nxtJ = j + jump.second;

            if(nxtI>=0 && nxtI<n && nxtJ>=0 && nxtJ<m)
            {
                nxt[node[i][j]] = node[nxtI][nxtJ];
            }
            else
            {
                nxt[node[i][j]] = exitNode;
            }
        }
    }

    int run = 0;
    for(int i = 0;i<n;i++)
    {
        for(int j = 0;j<m;j++)
        {
            run++;
            int x = node[i][j];

            while(true)
            {
                if(used[x]!=0)
                {
                    if(used[x]!=run) break;

                    int u = x;
                    do
                    {
                        compressedNodeVal[u] = x;
                        isCycle[u] = true;

                        u = nxt[u];
                    }
                    while(u!=x);

                    break;
                }
                else
                {
                    used[x] = run;
                    x = nxt[x];
                }
            }
        }
    }

    for(int i = 1;i<=n*m+5;i++)
    {
        if(compressedNodeVal[i]==0)
            compressedNodeVal[i] = i;
    }
}

int parent[MAXN*MAXN], depth[MAXN*MAXN], root[MAXN*MAXN];
vector <int> graph[MAXN*MAXN];

void DFSInit(int x, int last, int level, int currRoot)
{
    parent[x] = last;
    depth[x] = level;
    root[x] = currRoot;
    //cout << x << " " << level << '\n';

    for(int y: graph[x]) DFSInit(y, x, level+1, currRoot);
}

void buildGraph()
{
    for(int i = 1;i<=n*m+5;i++)
    {
        if(nxt[i]==0) continue;
        if(isCycle[i]==false)
        {
            graph[compressedNodeVal[nxt[i]]].push_back(i);
        }
    }

    DFSInit(exitNode, -1, 1, exitNode);
    for(int i = 1;i<=n*m+5;i++)
    {
        if(isCycle[i]==true && compressedNodeVal[i]==i) DFSInit(i, -1, 1, i);
    }
}

bool isOver(int x, int y)
{
    if(x==y) return true;
    if(y==-1) return false;

    return isOver(x, parent[y]);
}

int getDist(int x, int y)
{
    if(x==y) return 0;
    if(depth[compressedNodeVal[x]]>depth[compressedNodeVal[y]]) swap(x, y);

    return 1 + getDist(x, nxt[y]);
}

int query(int pos, int changeNode, int changeDir, int step)
{
    if(step>5) return -MAXN*MAXN*2;

    //cout << pos << " -- " << changeNode << '\n';
    if(isOver(compressedNodeVal[changeNode], compressedNodeVal[pos])==false)
    {
        if(root[compressedNodeVal[pos]]==exitNode) return depth[compressedNodeVal[pos]];
        return -MAXN*MAXN*2;
    }

    return query(changeDir, changeNode, changeDir, step+1) + getDist(changeNode, pos);
}

int main()
{
    //ios::sync_with_stdio(false);
    //cin.tie(NULL);

    cin >> n >> m;
    for(int i = 0;i<n;i++) cin >> a[i];
    init();

    return 0;
    buildGraph();


    int Q;
    cin >> Q;

    while(Q--)
    {
        char cD;
        int sI, sJ, cI, cJ;

        cin >> sI >> sJ >> cI >> cJ >> cD;
        sI--;sJ--;
        cI--;cJ--;

        int pos = node[sI][sJ];
        int changeNode = node[cI][cJ], changeDir = getNxt(cI, cJ, cD);

        int ans = query(pos, changeNode, changeDir, 0);

        if(ans<0) cout << "0" << '\n';
        else cout << ans << '\n';
    }

}
